@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for secretsmanager service client paginators.
 
@@ -16,11 +17,11 @@ Usage::
     list_secrets_paginator: ListSecretsPaginator = client.get_paginator("list_secrets")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, TYPE_CHECKING
-from botocore.paginate import Paginator as Boto3Paginator
-from mypy_boto3_secretsmanager.type_defs import ListSecretsResponseTypeDef, PaginatorConfigTypeDef
+from typing import Iterator
 
+from botocore.paginate import Paginator as Boto3Paginator
+
+from mypy_boto3_secretsmanager.type_defs import ListSecretsResponseTypeDef, PaginatorConfigTypeDef
 
 __all__ = ("ListSecretsPaginator",)
 
